@@ -126,8 +126,8 @@ OF_SUBCLASSING_RESTRICTED
 + (instancetype)archiveWithIRI: (OFIRI *)IRI mode: (OFString *)mode;
 
 /**
- * @brief Creates an IRI for accessing a the specified file within the
- *	  specified ZIP archive.
+ * @brief Creates an IRI for accessing the specified file within the specified
+ *	  ZIP archive.
  *
  * @param path The path of the file within the archive
  * @param IRI The IRI of the archive
